==> thefirstock-2.7.1-py3-none-any.whl: thefirstock/Variables/enums.py <==
"""
URLS for FIRSTOCK apiV2
"""

"""Login"""
LOGIN = 'https://connect.thefirstock.com/apiV2/login'

USERDETAILS = "https://connect.thefirstock.com/apiV2/userDetails"

LOGOUT = "https://connect.thefirstock.com/apiV2/logout"

PLACEORDER = "https://tradeapi.thefirstock.com/apiV2/placeOrder"

ORDERMARGIN = "https://connect.thefirstock.com/apiV2/orderMargin"

ORDERBOOK = "https://connect.thefirstock.com/apiV2/orderBook"

CANCELORDER = "https://connect.thefirstock.com/apiV2/cancelOrder"

MODIFYORDER = "https://connect.thefirstock.com/apiV2/modifyOrder"

SINGLEORDERHISTORY = "https://connect.thefirstock.com/apiV2/singleOrderHistory"

TRADEBOOK = "https://connect.thefirstock.com/apiV2/tradeBook"

POSITIONBOOK = "https://connect.thefirstock.com/apiV2/positionBook"

PRODUCTCONVERSION = "https://connect.thefirstock.com/apiV2/productConversion"

HOLDINGS = "https://connect.thefirstock.com/apiV2/holdings"

LIMITS = "https://connect.thefirstock.com/apiV2/limit"

GETQUOTES = "https://connect.thefirstock.com/apiV2/getQuotes"

SEARCHSCRIPS = "https://connect.thefirstock.com/apiV2/searchScrips"

GETSECURITYINFO = "https://connect.thefirstock.com/apiV2/securityInfo"

GETINDEXLIST = "https://connect.thefirstock.com/apiV2/indexList"

GETOPTIONCHAIN = "https://connect.thefirstock.com/apiV2/optionChain"

SPANCALCULATOR = "https://connect.thefirstock.com/apiV2/spanCalculators"

TIMEPRICESERIES = "https://connect.thefirstock.com/apiV2/timePriceSeries"

OPTIONGREEK = "https://connect.thefirstock.com/apiV2/optionGreek"

BASKETMARGIN = "https://connect.thefirstock.com/apiV2/basketMargin"

BEARPUTSPREAD = "https://connect.thefirstock.com/apiV2/strategies/bearPutSpread"

BULLCALLSPREAD = "https://connect.thefirstock.com/apiV2/strategies/bullCallSpread"

LONGSTRADDLE = "https://connect.thefirstock.com/apiV2/strategies/longStraddle"

LONGSTRANGLE = "https://connect.thefirstock.com/apiV2/strategies/longStrangle"

MULTIPLACEORDER = "https://connect.thefirstock.com/apiV2/strategies/multiPlaceOrders"

SHORTSTRADDLE = "https://connect.thefirstock.com/apiV2/strategies/shortStraddle"

SHORTSTRANGLE = "https://connect.thefirstock.com/apiV2/strategies/shortStrangle"

==> thefirstock-2.7.2-py3-none-any.whl: thefirstock/Variables/enums.py <==
"""
URLS for FIRSTOCK apiV2
"""

"""Login"""
LOGIN = 'https://connect.thefirstock.com/apiV2/login'

USERDETAILS = "https://connect.thefirstock.com/apiV2/userDetails"

LOGOUT = "https://connect.thefirstock.com/apiV2/logout"

PLACEORDER = "https://connect.thefirstock.com/apiV2/placeOrder"

ORDERMARGIN = "https://connect.thefirstock.com/apiV2/orderMargin"

ORDERBOOK = "https://connect.thefirstock.com/apiV2/orderBook"

CANCELORDER = "https://connect.thefirstock.com/apiV2/cancelOrder"

MODIFYORDER = "https://connect.thefirstock.com/apiV2/modifyOrder"

SINGLEORDERHISTORY = "https://connect.thefirstock.com/apiV2/singleOrderHistory"

TRADEBOOK = "https://connect.thefirstock.com/apiV2/tradeBook"

POSITIONBOOK = "https://connect.thefirstock.com/apiV2/positionBook"

PRODUCTCONVERSION = "https://connect.thefirstock.com/apiV2/productConversion"

HOLDINGS = "https://connect.thefirstock.com/apiV2/holdings"

LIMITS = "https://connect.thefirstock.com/apiV2/limit"

GETQUOTES = "https://connect.thefirstock.com/apiV2/getQuotes"

SEARCHSCRIPS = "https://connect.thefirstock.com/apiV2/searchScrips"

GETSECURITYINFO = "https://connect.thefirstock.com/apiV2/securityInfo"

GETINDEXLIST = "https://connect.thefirstock.com/apiV2/indexList"

GETOPTIONCHAIN = "https://connect.thefirstock.com/apiV2/optionChain"

SPANCALCULATOR = "https://connect.thefirstock.com/apiV2/spanCalculators"

TIMEPRICESERIES = "https://connect.thefirstock.com/apiV2/timePriceSeries"

OPTIONGREEK = "https://connect.thefirstock.com/apiV2/optionGreek"

BASKETMARGIN = "https://connect.thefirstock.com/apiV2/basketMargin"

BEARPUTSPREAD = "https://connect.thefirstock.com/apiV2/strategies/bearPutSpread"

BULLCALLSPREAD = "https://connect.thefirstock.com/apiV2/strategies/bullCallSpread"

LONGSTRADDLE = "https://connect.thefirstock.com/apiV2/strategies/longStraddle"

LONGSTRANGLE = "https://connect.thefirstock.com/apiV2/strategies/longStrangle"

MULTIPLACEORDER = "https://connect.thefirstock.com/apiV2/strategies/multiPlaceOrders"

SHORTSTRADDLE = "https://connect.thefirstock.com/apiV2/strategies/shortStraddle"

SHORTSTRANGLE = "https://connect.thefirstock.com/apiV2/strategies/shortStrangle"
